@@ -66,7 +66,9 @@ class MinimalConfluence:
         else:
             raise ValueError("At least one of title or page_id must not be None")
 
-    def create_page(self, space, title, body, parent_id=None, update_message=None):
+    def create_page(
+        self, space, title, body, parent_id=None, update_message=None, labels=None
+    ):
         """
         Create a new page in a space
 
@@ -76,6 +78,7 @@ class MinimalConfluence:
             body (str): the body of the page, in Confluence Storage Format
             parent_id (str or int): the ID of the parent page
             update_message (str): optional. A message that will appear in Confluence's history
+            labels (list(str)): optional. The set of labels the final page should have. None leaves existing labels unchanged
 
         Returns:
             The response from the API
@@ -96,9 +99,14 @@ class MinimalConfluence:
         if update_message is not None:
             page_structure["version"] = {"message": update_message}
 
+        if labels is not None:
+            page_structure["metadata"] = {
+                "labels": [{"name": label, "prefix": "global"} for label in labels]
+            }
+
         return self.api.content.post(json=page_structure)
 
-    def update_page(self, page, body, parent_id=None, update_message=None):
+    def update_page(self, page, body, parent_id=None, update_message=None, labels=None):
         update_structure = {
             "version": {
                 "number": page.version.number + 1,
@@ -116,6 +124,11 @@ class MinimalConfluence:
         if update_message is not None:
             update_structure["version"]["message"] = update_message
 
+        if labels is not None:
+            update_structure["metadata"] = {
+                "labels": [{"name": label, "prefix": "global"} for label in labels]
+            }
+
         return self.api.content.put(page.id, json=update_structure)
 
     def get_attachment(self, page, name):
@@ -151,5 +164,10 @@ class MinimalConfluence:
             files={"file": fp},
         )
 
+    def add_labels(self, page, labels):
+        return self.api.content(page.id).post(
+            "label", data=[{"name": label, "type": "global"} for label in labels]
+        )
+
     def get_url(self, page):
         return f"{page._links.base}{page._links.webui}"
